@@ -52,7 +52,7 @@ void SettingsWindow::selectSolvedColor()
 {
     QColor color(m_font_color_solved);
     color = QColorDialog::getColor(color, this);
-    if ( color.isValid() ) {
+    if (!color.isValid()) {
         return;
     }
     m_font_color_solved = color.name();
@@ -63,7 +63,7 @@ void SettingsWindow::selectUnsolvedColor()
 {
     QColor color(m_font_color_unsolved);
     color = QColorDialog::getColor(color, this);
-    if ( color.isValid() ) {
+    if (!color.isValid()) {
         return;
     }
     m_font_color_unsolved = color.name();
@@ -73,7 +73,7 @@ void SettingsWindow::selectUnsolvedColor()
 void SettingsWindow::bgToolButtonClicked()
 {
     QString fileName = QFileDialog::getOpenFileName(this, i18n("Select Background"), QString(),
-                                                    i18n("*.png *.jpg|Image Files (*.png *.jpg)") );
+                                                    i18n("Image Files (*.png *.jpg)"));
 
     if (fileName.isNull()) {
         return;
