@@ -19,6 +19,7 @@
 #include "config.h"
 
 #include <KAboutData>
+#include <KCrash>
 #include <KDBusService>
 #include <KLocalizedString>
 #include <QApplication>
@@ -46,12 +47,13 @@ int main(int argc, char *argv[])
                       i18n("Picmi - a nonogram puzzle game"),
                       KAboutLicense::GPL_V2,
                       i18n("(c) 2012 - 2015 The Picmi Authors"));
-    about.setHomepage("https://projects.kde.org/projects/kde/kdegames/picmi");
+    about.setHomepage("https://games.kde.org/picmi");
     about.addAuthor(i18n("Jakob Gruber"), i18n("Picmi Author"), "jakob.gruber@gmail.com");
 
 
     QCommandLineParser parser;
     KAboutData::setApplicationData(about);
+    KCrash::initialize();
     parser.addVersionOption();
     parser.addHelpOption();
     about.setupCommandLine(&parser);
